# PollingApp 

[![Run tests with Tox](https://github.com/unipoll/API/actions/workflows/tests.yaml/badge.svg)](https://github.com/unipoll/api/actions/workflows/tests.yaml)
[![Coverage Status](https://coveralls.io/repos/github/unipoll/api/badge.svg?branch=main)](https://coveralls.io/github/unipoll/api?branch=main)
[![GitHub Latest Release)](https://img.shields.io/github/v/release/unipoll/api?logo=github&label=Release%20Version&color=violet)](https://github.com/unipoll/API/releases)
[![Docker Image Version (latest semver)](https://img.shields.io/docker/v/unipoll/api?logo=docker&label=Docker%20Image&color=blue)](https://hub.docker.com/repository/docker/unipoll/api/tags)
[![PyPI - Version](https://img.shields.io/pypi/v/unipoll-api?logo=pypi&logoColor=yellow&label=PyPI%20Package&color=yellow)](https://pypi.org/project/unipoll-api/)


**This is the Development Branch**

### Useful Links:

- [Developer Wiki](https://github.com/unipoll/api/wiki) 

- [Polling API](https://api.unipoll.cc/)

- [Polling API Swagger Docs](https://api.unipoll.cc/docs)

- [Polling API Swagger ReDoc](https://api.unipoll.cc/redoc)

- [Postman Documentation](https://documenter.getpostman.com/view/19614303/2s9YR6ZDRA)
